.. _references:

References
==========

This section consists of the API documentation
of Red Bird. The classes, functions and methods
are documented here. Please see :ref:`tutorials <tutorial>`
for more thorough instruction of how to use the library. 

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   base_classes

